/*
 * config.h
 * Ansilove 4.1.0
 * https://www.ansilove.org
 *
 * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
 * All rights reserved.
 *
 * Ansilove is licensed under the BSD 2-Clause License.
 * See LICENSE file for details.
 */

#ifndef CONFIG_H
#define CONFIG_H

#include <stdint.h>

/* configuration defines */
#define VERSION "4.1.0"

enum {
	FONTS = 38,
	TYPES = 7
};

#endif /* CONFIG_H */
